@@ -5,6 +5,7 @@ import logging
 import os
 import signal
 import platform
+import asyncio
 import tornado
 import tornado.web
 from tornado.httpserver import HTTPServer
@@ -75,8 +76,9 @@ class App(tornado.web.Application):
         self.create_model()
         self.impmodule()
         self.handlers = route.get_routes(self.ROOT, self.handler_dir)
-        self.handlers.append((r'/docs', DocsHandler))
-        self.handlers.append((r'/.*', BaseHandler))
+        # self.handlers.append((r'/docs', DocsHandler))
+        self.handlers.append(tornado.web.url(r'/docs', DocsHandler, name=DocsHandler.__name__))
+        self.handlers.append(tornado.web.url(r'/.*', BaseHandler, name=BaseHandler.__name__))
         if not self.handlers:
             raise Exception("no api handler has been register.")
 
@@ -233,7 +235,6 @@ class App(tornado.web.Application):
         logging.warning("Server ROOT path: " + self.ROOT)
         logging.warning('Server Running on http://%s:%s' % (self.uri, self.port))
         if platform.system() == "Windows":
-            import asyncio
             asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
         http_server.start()
         ioloop = IOLoop.instance()
