@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
-
+import sys
 import json
 import logging
 import random
@@ -91,14 +91,13 @@ class BaseHandler(RequestHandler):
         elif status_code == 405:
             return self.write_failed(code=status_code, msg="HTTP 405: Method/URL Not Allowed", name="HTTP 405")
         elif status_code == 500:
-            import sys
             typ, value, tb = sys.exc_info()
             logging.error("Uncaught exception %s\n%r", self._request_summary(), self.request, exc_info=(typ, value, tb))
 
             error = kwargs["exc_info"][1]
             # 把除跨域异常外所有用raise抛出的内置异常类型，都转为200返回，内部保留500异常log
             if isinstance(error, errors.ApiError) and error.code != errors.ErrorCorsUri.code:
-                self.set_status(200, "HTTP STSTUS 200")
+                self.set_status(200, "HTTP STATUS 200")
 
             logging.error("异常时间：" + self.utils.int_to_date_string(self.utils.now(), "%Y-%m-%d %H:%M:%S"))
             if not hasattr(error, "message"):
@@ -108,7 +107,7 @@ class BaseHandler(RequestHandler):
                 logging.error("异常码：" + str(error.code))
                 logging.error("异常信息：" + error.message)
 
-            logging.error("参数:" + (json.dumps(self.params) if hasattr(self, "params") else "无"))
+            logging.error("参数:" + (json.dumps(self.params) if hasattr(self, "params") else str(self.request.arguments or {})))
             if not hasattr(error, "code_name") or not hasattr(error, "code"):
                 return self.write_failed()
             else:
@@ -814,6 +813,8 @@ class BaseSchema(object):
             d = {}
         if d and isinstance(d.get("_id"), ObjectId):
             d["_id"] = str(d["_id"])
+
+        d = cls.__parse_date(d)
         return d
 
     @classmethod
@@ -837,3 +838,19 @@ class BaseSchema(object):
                 else:
                     spec[k] = utils.to_ObjectId(v)
         return spec
+
+    @classmethod
+    def __parse_date(cls, d):
+        if not d:
+            return d
+
+        try:
+            for k in ["create_at", "update_at", "start_at", "end_at"]:
+                prefix, _ = k.split("_")
+                if k in d:
+                    if isinstance(d[k], str) and d[k].isdigit():
+                        d[k] = int(d[k])
+                    d["%s_date" % prefix] = utils.timestamp2str(d[k], "%Y-%m-%d %H:%M:%S")
+        except:
+            pass
+        return d
\ No newline at end of file
