@@ -40,20 +40,38 @@ def get_docs_agree():
 ## 一、约定说明
 ### 1.1 参数说明
 
-**参数位置：本框架规定了所有请求时，参数所配置的位置说明：**
-* query: 参数位置在？后面：http://www.domain.com/path?{name}={value}
-* form-data: 参数位置在body里,以multipart/form-data方式提交。通常表现为json格式
-* www-form: 参数位置在body里,以multipart/x-www-form-urlencoded方式提交。通常为表单键值对格式
-* file: 参数位置在body里,以multipart/form-data方式提交，常用户上传数据
-* raw：不建议
-* binary：不建议
+**请求方式：本框架规定了所有请求参数所配置的方式以及用途：**
+
+|参数位置|Content-Type|编码方式|举个例子|说明|
+|---|---|---|---|---|
+|path|--|--|/url/{user}/{uid}|拼接在url内|
+|query|--|--|/url/user?uid=10|拼接在?后|
+|body|application/x-www-form-urlencoded|x-www-form-urlencoded|'uid=100&sex=1'|表单提交，推荐|
+|body|application/json|x-www-form-urlencoded|'uid=100&sex=1'|json提交|
+|body|multipart/form-data|form-data|{"file": open("../demo.jpg")}|上传文件|
+
+* 1、path：参数被设置在请求url内；如"/url/xxx/yyy"。注意，使用该模式，框架不会自动收集参数，即self.params永远为空
+
+* 2、query：参数被设置在?后面：如"/url?xxx=111&yyy=222"
+
+* 3、body-json: json提交，参数以json的格式被设置在body内，body设置为x-www-form-urlencoded，Content-Type设置为"application/json"。注意该模式与body-form不能同时设置。
+
+* 4、body-form：表单提交，参数以kv的格式被设置在body内，body设置为x-www-form-urlencoded，Content-Type设置为"application/x-www-form-urlencoded"。注意该模式与body-json不能同时设置。
+
+* 5、file：上传文件。body设置为form-data，Content-Type设置为"multipart/form-data;boundary=abcefxxx",boundary通常会自动被设置为一个随机字符
+
+注意：以上345模式，由于值都被设置在body内，所以在同一api内，对于不同的参数，不允许混用不同的模式。唯一的例外是，file模式下（multipart/form-data），既允许同时上传文件，又允许设置其他参数。
 
 **参数值类型：在设置schema.yml时，指定type的值允许是以下几种之一**
-* int: 整形
-* float: 浮点型
-* str: 字符串
-* json: json串
-* file: 上传文件
+
+|类型|说明|
+|---|---|
+| int | 整形|
+| float | 浮点型|
+| str | 字符串|
+| list | 数组（不推荐)|
+| json | json串|
+| file | 文件|
 
 ### 1.2 headers
 API请求时，需要提供请求头
