@@ -22,6 +22,14 @@ to_json = lambda obj: json.dumps(obj, ensure_ascii=False, sort_keys=True)
 fix_path = lambda path: Path(path).as_posix()
 traceback = traceback
 
+num_or_alpha = re.compile("^(?!\d+$)[\da-zA-Z_]{5,10}$")                            # 仅数字和字母组合，不允许纯数字,长度5~10
+startwith_alpha = re.compile("^[a-zA-Z]{5,10}")                                     # 仅允许以字母开头,长度5~10
+lllegal_char = re.compile('^[_a-zA-Z0-9\u4e00-\u9fa5]+$')                           # 仅允许中文、英文、数字,_下划线。但不允许非法字符
+email_re = re.compile("^.+\\@(\\[?)[a-zA-Z0-9\\-\\.]+\\.([a-zA-Z]{2,3}|[0-9]{1,3})(\\]?)$")    # 是否是邮箱
+phone_re = re.compile("^(0|86|17951)?(13|14|15|16|17|18)[0-9]{9}$")                 # 11位手机号
+password_normal = re.compile("^(?:(?=.*)(?=.*[a-z])(?=.*[0-9])).{6,12}$")      # 一般密码 密码必须包含字母，数字,任意字符，长度6~12
+password_strong = re.compile("^(?:(?=.*[A-Z])(?=.*[a-z])(?=.*[0-9])).{6,12}$")      # 强密码 密码必须包含大小写，数字,任意字符，长度6~12
+
 def random_int(length=6):
     """生成随机的int 长度为length"""
     return ("%0" + str(length) + "d") % random.randint(int("1" + "0" * (length - 1)), int("9" * length))
@@ -258,3 +266,87 @@ def check2json(data):
     else:
         return data
 
+
+def verify_username(username, min: int =4, max: int =10):
+    """
+    校验用户名
+    :param username: 待验证用户名
+    :param min: 最小长度
+    :param max: 最大长度
+    :return:
+    """
+    re_str1 = re.compile("^[a-zA-Z](?!\d+$)[\da-zA-Z_]")      # 非数字开头
+    re_str2 = re.compile("^(?!\d+$)[\da-zA-Z_]{%d,%d}$" % (min, max))      # 非数字开头，字母与数字组合，长度4~10
+
+    return re.search(re_str1, username) and re.search(re_str2, username)
+
+def verify_nickname(nickname, min: int = 4, max: int = 10):
+    """
+    校验昵称
+    :param nickname: 待验证昵称
+    :param min: 最小长度
+    :param max: 最大长度
+    :return:
+    """
+    # 允许中文、字母、数字组合，禁止非法字符,长度4~10
+    lllegal_char = re.compile('^[_a-zA-Z0-9\u4e00-\u9fa5]{%d,%d}$' % (min, max))
+    return re.search(lllegal_char, nickname)
+
+def verify_password(password, min: int = 4, max: int = 10, strong=True):
+    """
+    校验密码
+    :param password: 待验证密码
+    :param min: 最小长度
+    :param max: 最大长度
+    :param strong: true 强密码 false 一般密码
+
+    :return:
+    """
+    password_normal = re.compile("^(?:(?=.*)(?=.*[a-z])(?=.*[0-9])).{%d,%d}$" % (min, max))  # 一般密码 密码必须包含字母，数字,任意字符，长度6~12
+    password_strong = re.compile("^(?:(?=.*[A-Z])(?=.*[a-z])(?=.*[0-9])).{%d,%d}$" % (min, max))  # 强密码 密码必须包含大小写，数字,任意字符，长度6~12
+
+    if strong:
+        return re.search(password_strong, password)
+    else:
+        return re.search(password_normal, password)
+
+def verify_phone(phone, min: int = 4, max: int = 10):
+    """
+    校验手机号
+    :param phone: 待验证phone
+    :param min: 最小长度
+    :param max: 最大长度
+
+    :return:
+    """
+    phone_re = re.compile("^(0|86|17951)?(13|14|15|16|17|18)[0-9]{9}$")                 # 11位手机号
+    return re.search(phone_re, phone)
+
+def verify_email(email, min: int = 4, max: int = 10):
+    """
+    校验邮箱
+    :param phone: 待验证邮箱
+    :param min: 最小长度
+    :param max: 最大长度
+
+    :return:
+    """
+    email_re = re.compile("^.+\\@(\\[?)[a-zA-Z0-9\\-\\.]+\\.([a-zA-Z]{2,3}|[0-9]{1,3})(\\]?)$")    # 是否是邮箱
+    return re.search(email_re, email)
+
+def verify_ip(ip, IPv6=True):
+    """
+    校验IP
+    :param phone: 待验证ip
+    :param min: 最小长度
+    :param max: 最大长度
+
+    :return:
+    """
+    ipv4_re = r"^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$"    # IPV4
+    ipv6_re = r"^(?:[A-F0-9]{1,4}:){7}[A-F0-9]{1,4}$"    # IPV6
+    if IPv6:    # 大小写不敏感
+        return re.search(ipv4_re, ip, re.I) or re.search(ipv6_re, ip)
+    else:
+        return re.search(ipv4_re, ip)
+
